@@ -1,10 +1,6 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
-from __future__ import division, print_function
-
 import pathlib
 
-from shapeout import settings
+from shapeout2 import settings
 
 
 def test_cfg_basic():
